#
# spec file for package jbig2dec
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _sover  0
Name:           jbig2dec
Version:        0.20
Release:        1.1
Summary:        JBIG2 Decoder Utility
License:        AGPL-3.0-or-later
URL:            https://jbig2dec.com
Source:         https://github.com/ArtifexSoftware/jbig2dec/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
# PATCH-FIX-UPSTREAM fix-for-restore-abi.patch deb#940605 -- Restores the ABI export of jbig2_ctx_new
Patch1:         fix-for-restore-abi.patch
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libpng)

%description
jbig2dec is a decoder utility implementing the JBIG2 bi-level image compression
spec. Also known as ITU T.88 and ISO IEC 14492, and included by reference in
Adobe's PDF version 1.4 and later.

%package -n libjbig2dec%{_sover}
Summary:        JBIG2 Decoder Library

%description -n libjbig2dec%{_sover}
jbig2dec is a decoder utility implementing the JBIG2 bi-level image compression
spec. Also known as ITU T.88 and ISO IEC 14492, and included by reference in
Adobe's PDF version 1.4 and later.

%package devel
Summary:        JBIG2 decoder development files
Requires:       libjbig2dec0 = %{version}

%description devel
This package contains development files needed for developing applications
based on libjbig2dec.

%prep
%autosetup -p1

%build
autoreconf -fiv
%configure \
  --disable-static \
  --with-libpng
%make_build

%install
%make_install
# Install missing header
install -c -m 644 memento.h %{buildroot}%{_includedir}/memento.h
rm %{buildroot}%{_libdir}/libjbig2dec.la

%post -n libjbig2dec0 -p /sbin/ldconfig
%postun -n libjbig2dec0 -p /sbin/ldconfig

%files
%doc CHANGES README
%license COPYING LICENSE
%{_bindir}/jbig2dec
%{_mandir}/man1/jbig2dec.1%{?ext_man}

%files -n libjbig2dec%{_sover}
%{_libdir}/libjbig2dec.so.*

%files devel
%{_includedir}/jbig2.h
%{_includedir}/memento.h
%{_libdir}/libjbig2dec.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Sat Oct 14 2023 Atri Bhattacharya <A.Bhattacharya@uliege.be>
- Update to version 0.20:
  * Move definition of inline macro so that it doesn't cause
    linker errors during cross-compilation.
  * Fix OSS-fuzz issue 10862, a memory leak, by freeing image
    resources upon error.
  * Fix a bug where a buffer was accessed without considering
    alignment requirements on architectures such as SPARC.
  * Fix compiler warnings.
  * Improve custom memory allocator used in testing to restricting
    memory usage.
  * Use silent automake rules when compiling as a separate
    project.
- Some specfile cleanups:
  * Drop additional CFLAGS/LDFLAGS passed for PIE; these are now
    taken care of by default build flags.
  * %%make_build instead of make.
- New Source URL.
* Sat Sep 12 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.19:
  * API change to use full 32 bit segment numbers, in accordance
    to the JBIG2 specification.
  * Better handling of end of input data stream and and when
    encountering errors in the arithmetic decoder stream. This
    should improve many situations where jbig2dec appeared to
    run forever.
  * Fix several bugs related to signedness or over-/underflow
    checks that were not robust.
  * Bug fixes for issues reported by Coverity/OSS-fuzz.
  * Add option to limit memory usage to command line tool.
  * Update manpages, and command line tool usage.
* Sun May 24 2020 Carsten Ziepke <kieltux@gmail.com>
- Add Patch fix-for-restore-abi.patch. Restore abi export of
  jbig2_ctx_new.
* Wed Apr 15 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.18
  * Performance enhancements related to decoding of MMR and
    generic regions as well as composing images onto pages.
  * Bug fixes for a few issues reported by Coverity and OSS-Fuzz.
    version 0.17:
  * Improved test suite by verifying input file contents and
    adding all ubc test streams. Fixed bugs where previously
    missing ubc test streams were decoded incorrectly.
  * Bug fixes for a few issues reported by Coverity.
  * Moved version number to jbig2.h, and adapted configure
    correspondingly. Added pkg-config file to be installed
    along side library.
    version 0.16:
  * API change allowing for library users to get the custom
    allocator so it may be freed if necessary. This is useful if
    the allocator is extended with e.g. a custom pointer needed
    by the allocator callbacks.
    version 0.15:
  * Bug fix release, with many security related and stability
    fixes as well as better tolerance/behaviour with out of spec
    files
- New upstream source
- Now running autoreconf before configure to avoid problems with
  the latter. Also build require automake and libtool for this
  purpose.
- Dropped Group tag
- Spec cleanup
* Sun Nov 19 2017 aloisio@gmx.com
- Use AGPL-3.0+ license
* Fri Nov 10 2017 aloisio@gmx.com
- Update to 0.14
  * Bug fix release
- Spec cleanup
* Wed May  4 2016 mpluskal@suse.com
- Update to 0.13
  * Bug fix release.
- Cleanup spec file with spec-cleaner
- Drop autoreconf call
- Update dependencies
* Thu Dec 10 2015 p.drouand@gmail.com
- Include missing memento.h
* Tue Dec  8 2015 p.drouand@gmail.com
- Update to version 0.12
  * Bug fix release
- Remove libpng-devel and xz requirements
- Add autoconf, automake and libtool build dependencies; need to
  run autoreconf
* Fri Feb 15 2013 badshah400@gmail.com
- Use the correct link to source tarball (from sourceforge)
- Add BuildRequires: xz, because source tarball is xz compressed
- Cleanup spec file.
* Wed Jan 16 2013 gber@opensuse.org
- clean up specfile further
- make jbig2dec-devel dpend on libjbig2dec0
* Thu Aug 16 2012 idonmez@suse.com
- Cleanup spec file
- Add baselibs.conf
* Sat Jul  7 2012 sleep_walker@suse.cz
- add -fPIC into CFLAGS
* Thu Jul  5 2012 sleep_walker@suse.cz
- accept wider convence for man page
* Thu Jul  5 2012 sleep_walker@suse.cz
- fix build for factory
* Wed Jul  4 2012 sleep_walker@suse.cz
- replace tarballs
* Wed Jul  4 2012 sleep_walker@suse.cz
- update to 0.11
* Tue Oct 27 2009 lnussel@suse.de
- initial package version 0.10
